@@ -17,8 +17,8 @@ public:
     SecuritySettings(QObject *parent = 0);
     virtual ~SecuritySettings();
 
-    bool sideloadingAllowed();
-    bool setSideloadingAllowed(bool allowed);
+    Q_DECL_DEPRECATED bool sideloadingAllowed();
+    Q_DECL_DEPRECATED bool setSideloadingAllowed(bool allowed);
 
     bool developerModeEnabled();
     Q_DECL_DEPRECATED void setDeveloperModeEnabled(bool enabled);
